@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2008 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2001-2010 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -77,7 +77,8 @@ buffer_at (const Buffer* buffer, BufferIterator pos)
 {       
 	assert (buffer);
 	assert (buffer->_data);
-	assert (pos >= buffer_begin(pos) && pos < buffer_end(buffer));
+	/* assert (pos >= buffer_begin(pos)); */
+	assert (pos < buffer_end(buffer));
 	
 	return buffer->_data[pos];
 }
@@ -117,7 +118,9 @@ buffer_data_pos (const Buffer* buffer, BufferIterator pos)
 	assert (buffer);
 	assert (buffer->_data);
 	assert (pos < buffer_length(buffer));
-	assert (pos >= 0 && pos < buffer_end(buffer));
+	/* assert (pos >= buffer_begin(pos)); */
+	assert (pos < buffer_end(buffer));
+
 
 	return buffer->_data + pos;
 }
@@ -178,7 +181,7 @@ buffer_find_offset (const Buffer *buffer, unsigned int offset, const char* patte
 	int match = 1;
 	
 	assert (buffer);
-	assert (buffer->_len >= 0);
+	/* assert (buffer->_len >= 0); */
 	assert (pattern || len == 0);
 	assert (offset < buffer->_len);
 	
