@@ -167,11 +167,13 @@ show_results (Buffer* buffer, int keep_entities)
 
 	if (buffer_length(output) != 0) {
 		/* strip trailing space */
-		for (j = buffer_end(output) - 1; j >= buffer_begin(output); --j) 
+		j = buffer_end (output) - 1;
+		do {
 			if (isalnum(buffer_at(output, j)))
 				break;
-		if (j >= buffer_begin(output))
-			buffer_erase (output, j + 1, buffer_end(output) - j - 1);
+		} while (j--);
+		
+		buffer_erase (output, j + 1, buffer_end(output) - j - 1);
 		
 		data = buffer_data_to_string (output);
 		fprintf (out, "%s\n", data);
